==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/Q1ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q1ExpressionDescription } from "./Q1ExpressionDescription";
/**
 * @hidden
 */
export let Q1ExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class Q1ExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (Q1ExpressionDescriptionMetadata.a == null) {
                Q1ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Q1ExpressionDescriptionMetadata.c(Q1ExpressionDescriptionMetadata.a);
            }
            if (a.k(Q1ExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(Q1ExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            Q1ExpressionDescriptionMetadata.b(a);
            a.ad("Q1Expression", () => new Q1ExpressionDescription());
            a.ac("Q1Expression", Q1ExpressionDescriptionMetadata.a);
        }
    }
    Q1ExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(Q1ExpressionDescriptionMetadata, 'Q1ExpressionDescriptionMetadata');
    Q1ExpressionDescriptionMetadata.a = null;
    return Q1ExpressionDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/Q1ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q1ExpressionDescription } from "./Q1ExpressionDescription";
/**
 * @hidden
 */
export let Q1ExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class Q1ExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (Q1ExpressionDescriptionMetadata.a == null) {
                Q1ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Q1ExpressionDescriptionMetadata.c(Q1ExpressionDescriptionMetadata.a);
            }
            if (a.k(Q1ExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(Q1ExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            Q1ExpressionDescriptionMetadata.b(a);
            a.ae("Q1Expression", () => new Q1ExpressionDescription());
            a.ad("Q1Expression", Q1ExpressionDescriptionMetadata.a);
        }
    }
    Q1ExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(Q1ExpressionDescriptionMetadata, 'Q1ExpressionDescriptionMetadata');
    Q1ExpressionDescriptionMetadata.a = null;
    return Q1ExpressionDescriptionMetadata;
})();
